Activity class

Constructors

Activity({required String id, required String name, required ActivitySettings settings, required Map<DateTime, ActivityData> data, required String userId})

Properties

data Map<DateTime, ActivityData>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings ActivitySettings
getter/setter pair
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited