AuthProvider class
- Mixed-in types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isAuthenticated → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String?
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
login(
String email, String password) → Future< void> -
logout(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
register(
String email, String password) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
sendPasswordResetEmail(
String email) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
tryAutoLogin(
) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited